UntrustedValue

Struct UntrustedValue 

pub struct UntrustedValue<Insecure> { /* private fields */ }
Represents an untrusted/untrustworthy value. The data contained inside this type is called tainted.

An attacker might be able to control (part) of the returned value. Take special care processing this data.

Taint can be cleared by using one of the traits SanitizeWith or SanitizeValue. Effectively, sanitizing the data.

This type does explicitly not implement common traits like Debug, Display, etc. since the data contained is considered untrusted. If desired you COULD implement these traits in for your custom types.

For naming purposes an untrusted value mapped inside this type is considered safe/trusted since it can not be accessed without sanitization.

Implementations

Source

impl<Insecure> UntrustedValue<Insecure>

Implementation of the UntrustedValue type.

pub fn use_untrusted_value(self) -> Insecure

Be sure that you carefully handle the returned value since it may be controllable by a malicious actor.

Does not perform any sanitization on the returned value.

Examples found in repository?
examples/untrusted_inputs_nested_structs.rs (line 35)
33    fn sanitize_value(self) -> Result<NetworkConfig, Self::Error> {
34        Ok(NetworkConfig {
35            port: self.port.use_untrusted_value(),
36            listen_address: self.listen_address.use_untrusted_value(),
37        }) // in real application: do some sanitizing
38    }
pub fn wrap(value: Insecure) -> Self

Wraps the provided value as UntrustedValue

Examples found in repository?
examples/untrusted_outputs.rs (line 18)
14fn main() {
15    // call library function
16    assert_eq!(
17        some_lib_func().type_id(),
18        UntrustedValue::wrap("test".to_string()).type_id()
19    );
20}