pub struct UntrustedValue<Insecure> { /* private fields */ }Expand description
Represents an untrusted/untrustworthy value. The data contained inside this type is called tainted.
An attacker might be able to control (part) of the returned value. Take special care processing this data.
Taint can be cleared by using one of the traits SanitizeWith or SanitizeValue.
Effectively, sanitizing the data.
This type does explicitly not implement common traits like Debug, Display, etc. since the data contained is considered untrusted. If desired you COULD implement these traits in for your custom types.
For naming purposes an untrusted value mapped inside this type is considered safe/trusted since it can not be accessed without sanitization.
Implementations
Sourceimpl<Insecure> UntrustedValue<Insecure>
Implementation of the UntrustedValue type.
impl<Insecure> UntrustedValue<Insecure>
Implementation of the UntrustedValue type.
Sourcepub fn use_untrusted_value(self) -> Insecure
pub fn use_untrusted_value(self) -> Insecure
Be sure that you carefully handle the returned value since it may be controllable by a malicious actor.
Does not perform any sanitization on the returned value.
Sourcepub fn wrap(value: Insecure) -> Self
pub fn wrap(value: Insecure) -> Self
Wraps the provided value as UntrustedValue